==> daemonshogi-0.1.3.tar.gz: daemonshogi-0.1.3/src/si/misc.c <==
/* SI SHOGI Library
   Copyright (C) 2002 Masahiko Tokita
   This file is part of the SI SHOGI Library.

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2.1 of the License, or (at your option) any later version.w

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General Public
   License along with The Daemonshogi; if not, write to the Free
   Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
   02111-1307 USA.  */
/*
 * misc.c
 * $Source: /cvs/si/misc.c,v $
 * $Id: misc.c,v 1.20 2002/09/11 21:17:26 mik Exp $
 */

#include <stdio.h>
#include <stdlib.h>
#include <assert.h>
#include "si.h"

/**
 * ̿Ū顼ȯȤ˸ƤФ(ưɬפʥ꤬ݤǤ
 * ʤä)
 * @param s 顼Ƥɽʸ
 */
void si_abort(char *s) {
  printf("is_abort : %s\n", s);
  abort();
}

/**
 * buf ˻֤ɽʸǼ롣
 * 00:00:00 ηɽ롣Ƥ :ʬ:á
 *  t 100 ְʾλ֤ǼƤ 99 ֤Ȥɽ롣
 * buf ˤ BUFSIZ ʾΥ꤬ݤƤ뤳ȤꤷƤ롣
 * @param buf ǼΥݥ
 * @param t ɽ()
 */
void time2string(char *buf, time_t t) {
  int hour;
  int minute;
  int second;

#ifdef DEBUG
  assert( buf != NULL );
#endif /* DEBUG */
  
  hour = t / 3600;
  if ( 99 < hour ) {
    hour = 99;
  }

  minute = (t % 3600) / 60;
  if ( 59 < minute ) {
    minute = 59;
  }
  
  second = t % 60;

  sprintf(buf, "%02d:%02d:%02d", hour, minute, second);
}

#ifndef USE_MISC_MACRO

/**
 * bo  (x,y) ΰ֤ζ𤬸ζä󥼥֤
 * ʳ(ζ𡢶𤬤ʤ)ξϥ֤
 * @param bo оݤBOARD
 * @param x Xɸΰ
 * @param y Yɸΰ
 */
int isGote(BOARD *bo, int x, int y) {
#ifdef DEBUG
  assert( bo != NULL );
  assert( 0 <= x && x <=10 );
  assert( 0 <= y && y <=10 );
#endif /* DEBUG */
  return (bo->board[ (y<<4) + x ]) & 0x10;
}

/**
 * μ֤֤0ʤꡢ1ʤиꡣ
 * @param p 
 * @return 0ʤꡢ1ʤиꡣ
 */
int getTeban(int p) {
#ifdef DEBUG
  assert( p != 0 );
  assert( p != WALL );
#endif /* DEBUG */
  
  return (p & 0x10) == 0x10;
}

#endif /* USE_MISC_MACRO */

/**
 * ζǤϤʤ 1 ֤
 * 
 * @param p 
 * @return 
 */
int notSentePiece(int p) {
#ifdef DEBUG
  assert( p != WALL );
#endif /* DEBUG */

  if ( p == 0 )
    return 1;
  
  if ( (p & 0x10) == 0x10 )
    return 1;
  
  return 0;
}

/**
 * ζǤϤʤ 1 ֤
 * 
 * @param p 
 * @return 
 */
int notGotePiece( int p ) {
#ifdef DEBUG
  assert( p != WALL );
#endif /* DEBUG */

  if ( p == 0 )
    return 1;
  
  if ( (p & 0x10) == 0x10 )
    return 0;
  
  return 1;
}

/**
 * ꤷx⤬뤫Ĵ٤롣
 * ä餽 Y ɸ֤ʤä 0 ֤
 * @param bo Ĵ٤BOARD
 * @param x ꤹx
 * @return ʤä 0 ä Yɸ(19)֤
 */
int checkFuSente(BOARD *bo, int x) {
  int i;

#ifdef DEBUG
  assert( bo != NULL );
  assert( 1 <= x && x <= 9 );
#endif /* DEBUG */

  for (i=0x10; i<=0x99; i+=0x10) {
    if ( bo->board[ i + x ] == FU ) {
      return i >> 4;
    }
  }

  return 0;
}

/**
 * ꤷx˸⤬뤫Ĵ٤롣
 * ä餽 Y ɸ֤ʤä0֤
 * @param bo Ĵ٤BOARD
 * @param x ꤹx
 * @return ʤä 0 ä Yɸ(19)֤
 */
int checkFuGote(BOARD *bo, int x) {
  int i;

#ifdef DEBUG
  assert( bo != NULL );
  assert( 1 <= x && x <= 9 );
#endif /* DEBUG */

  for (i=0x10; i<=0x99; i+=0x10) {
    if ( bo->board[ i + x ] == FU + 0x10 ) {
      return i >> 4;
    }
  }

  return 0;
}

==> daemonshogi-0.1.4.tar.gz: daemonshogi-0.1.4/src/si/misc.c <==
/* SI SHOGI Library
   Copyright (C) 2002 Masahiko Tokita
   This file is part of the SI SHOGI Library.

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2.1 of the License, or (at your option) any later version.w

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General Public
   License along with The Daemonshogi; if not, write to the Free
   Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
   02111-1307 USA.  */
/*
 * misc.c
 * $Source: /cvsroot/daemonshogi/daemonshogi/src/si/misc.c,v $
 * $Id: misc.c,v 1.1.1.1 2005/12/09 09:03:09 tokita Exp $
 */

#include <stdio.h>
#include <stdlib.h>
#include <assert.h>
#include "si.h"

/**
 * ̿Ū顼ȯȤ˸ƤФ(ưɬפʥ꤬ݤǤ
 * ʤä)
 * @param s 顼Ƥɽʸ
 */
void si_abort(char *s) {
  printf("is_abort : %s\n", s);
  abort();
}

/**
 * buf ˻֤ɽʸǼ롣
 * 00:00:00 ηɽ롣Ƥ :ʬ:á
 *  t 100 ְʾλ֤ǼƤ 99 ֤Ȥɽ롣
 * buf ˤ BUFSIZ ʾΥ꤬ݤƤ뤳ȤꤷƤ롣
 * @param buf ǼΥݥ
 * @param t ɽ()
 */
void time2string(char *buf, time_t t) {
  int hour;
  int minute;
  int second;

#ifdef DEBUG
  assert( buf != NULL );
#endif /* DEBUG */
  
  hour = t / 3600;
  if ( 99 < hour ) {
    hour = 99;
  }

  minute = (t % 3600) / 60;
  if ( 59 < minute ) {
    minute = 59;
  }
  
  second = t % 60;

  sprintf(buf, "%02d:%02d:%02d", hour, minute, second);
}

#ifndef USE_MISC_MACRO

/**
 * bo  (x,y) ΰ֤ζ𤬸ζä󥼥֤
 * ʳ(ζ𡢶𤬤ʤ)ξϥ֤
 * @param bo оݤBOARD
 * @param x Xɸΰ
 * @param y Yɸΰ
 */
int isGote(BOARD *bo, int x, int y) {
#ifdef DEBUG
  assert( bo != NULL );
  assert( 0 <= x && x <=10 );
  assert( 0 <= y && y <=10 );
#endif /* DEBUG */
  return (bo->board[ (y<<4) + x ]) & 0x10;
}

/**
 * μ֤֤0ʤꡢ1ʤиꡣ
 * @param p 
 * @return 0ʤꡢ1ʤиꡣ
 */
int getTeban(int p) {
#ifdef DEBUG
  assert( p != 0 );
  assert( p != WALL );
#endif /* DEBUG */
  
  return (p & 0x10) == 0x10;
}

#endif /* USE_MISC_MACRO */

/**
 * ζǤϤʤ 1 ֤
 * 
 * @param p 
 * @return 
 */
int notSentePiece(int p) {
#ifdef DEBUG
  assert( p != WALL );
#endif /* DEBUG */

  if ( p == 0 )
    return 1;
  
  if ( (p & 0x10) == 0x10 )
    return 1;
  
  return 0;
}

/**
 * ζǤϤʤ 1 ֤
 * 
 * @param p 
 * @return 
 */
int notGotePiece( int p ) {
#ifdef DEBUG
  assert( p != WALL );
#endif /* DEBUG */

  if ( p == 0 )
    return 1;
  
  if ( (p & 0x10) == 0x10 )
    return 0;
  
  return 1;
}

/**
 * ꤷx⤬뤫Ĵ٤롣
 * ä餽 Y ɸ֤ʤä 0 ֤
 * @param bo Ĵ٤BOARD
 * @param x ꤹx
 * @return ʤä 0 ä Yɸ(19)֤
 */
int checkFuSente(BOARD *bo, int x) {
  int i;

#ifdef DEBUG
  assert( bo != NULL );
  assert( 1 <= x && x <= 9 );
#endif /* DEBUG */

  for (i=0x10; i<=0x99; i+=0x10) {
    if ( bo->board[ i + x ] == FU ) {
      return i >> 4;
    }
  }

  return 0;
}

/**
 * ꤷx˸⤬뤫Ĵ٤롣
 * ä餽 Y ɸ֤ʤä0֤
 * @param bo Ĵ٤BOARD
 * @param x ꤹx
 * @return ʤä 0 ä Yɸ(19)֤
 */
int checkFuGote(BOARD *bo, int x) {
  int i;

#ifdef DEBUG
  assert( bo != NULL );
  assert( 1 <= x && x <= 9 );
#endif /* DEBUG */

  for (i=0x10; i<=0x99; i+=0x10) {
    if ( bo->board[ i + x ] == FU + 0x10 ) {
      return i >> 4;
    }
  }

  return 0;
}
